@@ -30,7 +30,7 @@ module RubyParams
 
   RUBY_PATH  = File.join( BINDIR, RUBY )
 
-  DL_EXT     = CONFIG['DLEXT']
-  Extentions = [ 'rb', DL_EXT ]
+  DLEXT      = CONFIG['DLEXT']
+  Extentions = [ 'rb', DLEXT ]
 
 end
